@@ -15,17 +15,21 @@
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
 package Graphics::Fig::Ellipse;
-our $VERSION = 'v1.0.2';
+our $VERSION = 'v1.0.6';
 
 use strict;
 use warnings;
 use Carp;
 use Math::Trig;
-use Regexp::Common qw /number/;
 use Graphics::Fig::Color;
 use Graphics::Fig::Matrix;
 use Graphics::Fig::Parameters;
 
+#
+# RE_INT: regular expression matching an integer
+#
+my $RE_INT = "(?:(?:[-+]?)(?:[0123456789]+))";
+
 #
 # Graphics::Fig::Ellipse::generalToCanonical
 #   ( $A, $B, $C, $D, $E, $F )
@@ -79,7 +83,7 @@ sub _convertCircleSubtype {
     if ($value eq "diameter") {
 	return 4;
     }
-    if ($value =~ m/^$RE{num}{int}$/) {
+    if ($value =~ m/^$RE_INT$/) {
 	if ($value != 3 && $value != 4) {
 	    croak("${prefix}: ${value}: error: " .
 	    	    "expected integer between 3 and 4");
@@ -108,7 +112,7 @@ sub _convertEllipseSubtype {
     if ($value eq "diameters") {
 	return 2;
     }
-    if ($value =~ m/^$RE{num}{int}$/) {
+    if ($value =~ m/^$RE_INT$/) {
 	if ($value != 1 && $value != 2) {
 	    croak("${prefix}: ${value}: error: " .
 	    	    "expected integer between 1 and 2");
@@ -587,11 +591,11 @@ sub ellipse {
 	} elsif (@{$points} == 5) {
 	    if (defined($parameters{"center"})) {
 		croak("ellipse: error: center may not be given " .
-		      "with 3 points");
+		      "with 5 points");
 	    }
 	    if (defined($parameters{"rotation"})) {
 		croak("ellipse: error: rotation may not be given " .
-		      "with 3 points");
+		      "with 5 points");
 	    }
 
 	    #
@@ -766,7 +770,7 @@ sub scale {
 }
 
 #
-# Graphics::Fig::Polyline return [[xmin, ymin], [xmax, ymax]]
+# Graphics::Fig::Elliipse return [[xmin, ymin], [xmax, ymax]]
 #   $self:       object
 #   $parameters: getbbox parameters
 #
