@@ -14,8 +14,9 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-use 5.014;
-package Graphics::Fig::Matrix v1.0.1;
+package Graphics::Fig::Matrix;
+our $VERSION = 'v1.0.6';
+
 use strict;
 use warnings;
 use Carp;
@@ -60,13 +61,14 @@ sub reduce {
 	}
 	if ($max_idx != $i) {
 	    ( ${$a}[$i], ${$a}[$max_idx] ) = ( ${$a}[$max_idx], ${$a}[$i] );
+	    $d = -$d;
 	}
 
 	#
 	# Scale pivot to 1.0.
 	#
 	$scale = ${$a}[$i][$j];
-	$d *= $scale;
+	$d /= $scale;
 	for (my $s = $j; $s < $n; ++$s) {
 	    ${$a}[$i][$s] /= $scale;
 	}
